summaryrefslogtreecommitdiff
path: root/minecctl/misc-commands.c
diff options
context:
space:
mode:
Diffstat (limited to 'minecctl/misc-commands.c')
-rw-r--r--minecctl/misc-commands.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/minecctl/misc-commands.c b/minecctl/misc-commands.c
index 52797da..f20cac5 100644
--- a/minecctl/misc-commands.c
+++ b/minecctl/misc-commands.c
@@ -9,9 +9,9 @@ bool do_list(struct cfg *cfg)
{
struct server *server;
/* server->filename check excludes servers created from cmdline */
list_for_each_entry(server, &cfg->servers, list)
- if (server->filename)
+ if (server->scfg.filename)
info("%s", server->name);
return true;
@@ -9,9 +9,9 @@ bool do_list(struct cfg *cfg)
{
struct server *server;
- /* server->filename check excludes servers created from cmdline */
+ /* server->scfg.filename check excludes servers created from cmdline */
list_for_each_entry(server, &cfg->servers, list)